@@ -13,24 +13,21 @@ mod tests {
             return;
         }
 
-        let impl_concretizations = impl_concretizations_directory_from_target(
-            "auto_concretize",
-            "auto_concretize::target",
-        );
+        let impl_concretizations =
+            impl_concretizations_directory_from_target("auto_concretize", "target");
 
         remove_dir_all(&impl_concretizations).unwrap_or_default();
 
-        let concretizations =
-            concretizations_directory_from_target("auto_concretize", "auto_concretize::target");
+        let concretizations = concretizations_directory_from_target("auto_concretize", "target");
 
         remove_dir_all(&concretizations).unwrap_or_default();
 
-        examples::test("auto_concretize", "auto_concretize::test")
+        examples::test("auto_concretize", "test")
             .unwrap()
             .assert()
             .success();
 
-        examples::test_fuzz("auto_concretize", "auto_concretize::target")
+        examples::test_fuzz("auto_concretize", "target")
             .unwrap()
             .args(&["--no-run"])
             .assert()
